@@ -1,8 +1,8 @@
 //! ## Usage
 //! \
-//! 
+//!
 //! **Sender example**
-//! 
+//!
 //! ```
 //! let sock = UdpSocket::bind("0.0.0.0:3456")
 //!     .await
@@ -12,11 +12,11 @@
 //! send_file(&sock, "recieve_destination", SocketAddr::from_str("127.0.0.1:7890"))
 //!     .await
 //!     .expect("error when sending file");
-//! ``` 
+//! ```
 //! \
-//! 
+//!
 //! **Reciever example**
-//! 
+//!
 //! ```
 //! let sock = UdpSocket::bind("0.0.0.0:7890")
 //!     .await
@@ -31,9 +31,9 @@
 //! .await
 //! .expect("error when sending file");
 //! ```
-//! 
+//!
 //! ## Sending files
-//! 
+//!
 //! ### Messages
 //!
 //! Messages are 508 bytes in size. This is because that is the biggest message you can send over
@@ -54,21 +54,21 @@
 //! 1. Client A sends a udp message to client B:s ip-address and port.
 //! 2. Client B does the same as client A but with client A:s ip-address and port.
 //! 3. Now they are able to send messages over udp from where they have hole-punched to.
-//! 
+//!
 //! ### Progress tracking
 //!
 //! When recieving the reciever remembers what messages have been sent.
 //! It also knows how many that should be sent.
 //! With that info it can tell the sender what messages are unsent.
-//! 
+//!
 //! The progress tracking can be stored in memory and on file if the messages are to many.
-//! 
+//!
 //! You can **calculate** the memory required for recieving a file, file size / 500 / 8 = size of progress tracker.
-//! 
+//!
 //! **Example**: 64gb = 64 000 000 000 / 500 / 8 = 16 000 000 = 16mb
-//! 
+//!
 //! The progress tracker for 64gb is 16mb.
-//! 
+//!
 //! ### Sending
 //!
 //! It sends the file by sending many messages.
@@ -82,7 +82,8 @@ use std::{
     error::Error,
     fs::File,
     io::{self},
-    net::SocketAddr,
+    net::{IpAddr, Ipv4Addr, SocketAddr},
+    sync::Arc,
     time::Duration,
 };
 
@@ -205,3 +206,23 @@ async fn recv(
         }
     }
 }
+
+pub enum Source {
+    SocketArc(Arc<UdpSocket>),
+    Socket(UdpSocket),
+    Port(u16),
+}
+
+impl Source {
+    async fn into_socket(self) -> Arc<UdpSocket> {
+        match self {
+            Source::SocketArc(s) => s,
+            Source::Socket(s) => Arc::new(s),
+            Source::Port(port) => Arc::new(
+                UdpSocket::bind(SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), port))
+                    .await
+                    .unwrap(),
+            ),
+        }
+    }
+}
